@@ -3,3 +3,6 @@ from .models import GenerativeT5, SimplifiedT5Encoder, CombinedDecoder
 
 # Huggingface utilities
 from .huggingface_utilities import create_t5_encoder_decoder, generate_onnx_representation
+
+# API
+from .api import get_sess
